onetbb: oneAPI Threading Building Blocks
========================================

Description
-----------

C++ parallelization library


License
-------

Apache License, Version 2.0


Upstream Contact
----------------

https://github.com/oneapi-src/oneTBB
